:orphan:

The ``pyladies`` kit gets you up and running with starting a PyLadies local chapter, including what's needed, advice, event planning help, and some tools that may be helpful.

The ``pyladies`` package is licensed under the `Creative Commons Attribution 3.0 Unported License`_.

.. _Creative Commons Attribution 3.0 Unported License: http://creativecommons.org/licenses/by/3.0/

You are free to use all the graphics in this kit to print your own t-shirts, stickers, and other merchandise with one restriction: if you are selling these items, marking up the price is fine as long as profits goes toward anything women in Python/open-source/computing related. (We encourage you to use merchandise based on graphics in this kit to raise funds for starting or growing your PyLadies chapter, or hosting PyLadies meetups at conferences!)